package com.ruoyi.web.controller.cxxm;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.cxxm.domain.TaskCheck;
import com.ruoyi.cxxm.service.ITaskCheckService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务巡查记录Controller
 *
 * @author ruoyi
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/cxxm/check")
public class TaskCheckController extends BaseController
{
    @Autowired
    private ITaskCheckService taskCheckService;

/**
 * 查询任务巡查记录列表
 */
@PreAuthorize("@ss.hasPermi('cxxm:check:list')")
@GetMapping("/list")
    public TableDataInfo list(TaskCheck taskCheck, PageDomain pageDomain)
    {
        startPage();
        List<TaskCheck> list = taskCheckService.list(new QueryWrapper<>(taskCheck));
        return getDataTable(list);
    }

    /**
     * 导出任务巡查记录列表
     */
    @PreAuthorize("@ss.hasPermi('cxxm:check:export')")
    @Log(title = "任务巡查记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskCheck taskCheck)
    {
        List<TaskCheck> list = taskCheckService.list(new QueryWrapper<>(taskCheck));
        ExcelUtil<TaskCheck> util = new ExcelUtil<TaskCheck>(TaskCheck.class);
        util.exportExcel(response, list, "任务巡查记录数据");
    }

    /**
     * 获取任务巡查记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:check:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(taskCheckService.getById(id));
    }

    /**
     * 新增任务巡查记录
     */
    @PreAuthorize("@ss.hasPermi('cxxm:check:add')")
    @Log(title = "任务巡查记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TaskCheck taskCheck)
    {
        return toAjax(taskCheckService.save(taskCheck));
    }

    /**
     * 修改任务巡查记录
     */
    @PreAuthorize("@ss.hasPermi('cxxm:check:edit')")
    @Log(title = "任务巡查记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TaskCheck taskCheck)
    {
        return toAjax(taskCheckService.updateById(taskCheck));
    }

    /**
     * 删除任务巡查记录
     */
    @PreAuthorize("@ss.hasPermi('cxxm:check:remove')")
    @Log(title = "任务巡查记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(taskCheckService.removeByIds(ids));
    }
}

