package com.ruoyi.web.controller.cxxm;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.cxxm.domain.TaskCheckImage;
import com.ruoyi.cxxm.service.ITaskCheckImageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务巡查图片Controller
 *
 * @author ruoyi
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/cxxm/image")
public class TaskCheckImageController extends BaseController
{
    @Autowired
    private ITaskCheckImageService taskCheckImageService;

/**
 * 查询任务巡查图片列表
 */
@PreAuthorize("@ss.hasPermi('cxxm:image:list')")
@GetMapping("/list")
    public TableDataInfo list(TaskCheckImage taskCheckImage, PageDomain pageDomain)
    {
        startPage();
        List<TaskCheckImage> list = taskCheckImageService.list(new QueryWrapper<>(taskCheckImage));
        return getDataTable(list);
    }

    /**
     * 导出任务巡查图片列表
     */
    @PreAuthorize("@ss.hasPermi('cxxm:image:export')")
    @Log(title = "任务巡查图片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskCheckImage taskCheckImage)
    {
        List<TaskCheckImage> list = taskCheckImageService.list(new QueryWrapper<>(taskCheckImage));
        ExcelUtil<TaskCheckImage> util = new ExcelUtil<TaskCheckImage>(TaskCheckImage.class);
        util.exportExcel(response, list, "任务巡查图片数据");
    }

    /**
     * 获取任务巡查图片详细信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:image:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(taskCheckImageService.getById(id));
    }

    /**
     * 新增任务巡查图片
     */
    @PreAuthorize("@ss.hasPermi('cxxm:image:add')")
    @Log(title = "任务巡查图片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TaskCheckImage taskCheckImage)
    {
        return toAjax(taskCheckImageService.save(taskCheckImage));
    }

    /**
     * 修改任务巡查图片
     */
    @PreAuthorize("@ss.hasPermi('cxxm:image:edit')")
    @Log(title = "任务巡查图片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TaskCheckImage taskCheckImage)
    {
        return toAjax(taskCheckImageService.updateById(taskCheckImage));
    }

    /**
     * 删除任务巡查图片
     */
    @PreAuthorize("@ss.hasPermi('cxxm:image:remove')")
    @Log(title = "任务巡查图片", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(taskCheckImageService.removeByIds(ids));
    }
}

