package com.ruoyi.web.controller.cxxm;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.cxxm.domain.TaskCheckVideo;
import com.ruoyi.cxxm.service.ITaskCheckVideoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务巡查视频Controller
 *
 * @author ruoyi
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/cxxm/video")
public class TaskCheckVideoController extends BaseController
{
    @Autowired
    private ITaskCheckVideoService taskCheckVideoService;

/**
 * 查询任务巡查视频列表
 */
@PreAuthorize("@ss.hasPermi('cxxm:video:list')")
@GetMapping("/list")
    public TableDataInfo list(TaskCheckVideo taskCheckVideo, PageDomain pageDomain)
    {
        startPage();
        List<TaskCheckVideo> list = taskCheckVideoService.list(new QueryWrapper<>(taskCheckVideo));
        return getDataTable(list);
    }

    /**
     * 导出任务巡查视频列表
     */
    @PreAuthorize("@ss.hasPermi('cxxm:video:export')")
    @Log(title = "任务巡查视频", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskCheckVideo taskCheckVideo)
    {
        List<TaskCheckVideo> list = taskCheckVideoService.list(new QueryWrapper<>(taskCheckVideo));
        ExcelUtil<TaskCheckVideo> util = new ExcelUtil<TaskCheckVideo>(TaskCheckVideo.class);
        util.exportExcel(response, list, "任务巡查视频数据");
    }

    /**
     * 获取任务巡查视频详细信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:video:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(taskCheckVideoService.getById(id));
    }

    /**
     * 新增任务巡查视频
     */
    @PreAuthorize("@ss.hasPermi('cxxm:video:add')")
    @Log(title = "任务巡查视频", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TaskCheckVideo taskCheckVideo)
    {
        return toAjax(taskCheckVideoService.save(taskCheckVideo));
    }

    /**
     * 修改任务巡查视频
     */
    @PreAuthorize("@ss.hasPermi('cxxm:video:edit')")
    @Log(title = "任务巡查视频", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TaskCheckVideo taskCheckVideo)
    {
        return toAjax(taskCheckVideoService.updateById(taskCheckVideo));
    }

    /**
     * 删除任务巡查视频
     */
    @PreAuthorize("@ss.hasPermi('cxxm:video:remove')")
    @Log(title = "任务巡查视频", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(taskCheckVideoService.removeByIds(ids));
    }
}

