package com.ruoyi.web.controller.cxxm;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.cxxm.domain.Tbxx;
import com.ruoyi.cxxm.service.ITbxxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 图斑信息Controller
 *
 * @author ruoyi
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/cxxm/tbxx")
public class TbxxController extends BaseController
{
    @Autowired
    private ITbxxService tbxxService;

/**
 * 查询图斑信息列表
 */
@PreAuthorize("@ss.hasPermi('cxxm:tbxx:list')")
@GetMapping("/list")
    public TableDataInfo list(Tbxx tbxx, PageDomain pageDomain)
    {
        startPage();
        List<Tbxx> list = tbxxService.list(new QueryWrapper<>(tbxx));
        return getDataTable(list);
    }

    /**
     * 导出图斑信息列表
     */
    @PreAuthorize("@ss.hasPermi('cxxm:tbxx:export')")
    @Log(title = "图斑信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Tbxx tbxx)
    {
        List<Tbxx> list = tbxxService.list(new QueryWrapper<>(tbxx));
        ExcelUtil<Tbxx> util = new ExcelUtil<Tbxx>(Tbxx.class);
        util.exportExcel(response, list, "图斑信息数据");
    }

    /**
     * 获取图斑信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:tbxx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tbxxService.getById(id));
    }

    /**
     * 新增图斑信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:tbxx:add')")
    @Log(title = "图斑信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Tbxx tbxx)
    {
        return toAjax(tbxxService.save(tbxx));
    }

    /**
     * 修改图斑信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:tbxx:edit')")
    @Log(title = "图斑信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Tbxx tbxx)
    {
        return toAjax(tbxxService.updateById(tbxx));
    }

    /**
     * 删除图斑信息
     */
    @PreAuthorize("@ss.hasPermi('cxxm:tbxx:remove')")
    @Log(title = "图斑信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(tbxxService.removeByIds(ids));
    }
}

